@@ -10,9 +10,9 @@
 ## Parallel::Loops is based on Parallel::ForkManager.
 ##
 ## Parallel::Loops..:       600  Forking each @input is expensive
-## MCE foreach......:    21,500  Sends result after each @input
-## MCE forseq.......:    64,000  Loops through sequence of numbers
-## MCE forchunk.....:   450,000  Chunking reduces overhead
+## MCE foreach......:    34,000  Sends result after each @input
+## MCE forseq.......:    70,000  Loops through sequence of numbers
+## MCE forchunk.....:   480,000  Chunking reduces overhead
 ##
 ## usage: foreach.pl [ size ]
 ##
@@ -52,8 +52,7 @@ my $order_id    = 1;
 
 sub display_result {
 
-   my ($wk_result, $chunk_id) = @_;
-   $result{$chunk_id} = $wk_result;
+   $result{$_[1]} = $_[0];
 
    while (1) {
       last unless exists $result{$order_id};
@@ -61,15 +60,17 @@ sub display_result {
       printf "n: %d sqrt(n): %f\n",
          $input_data[$order_id - 1], $result{$order_id};
 
-      delete $result{$order_id};
-      $order_id++;
+      delete $result{$order_id++};
    }
+
+   return;
 }
 
 ## Compute via MCE.
 
 my $mce = MCE->new(
-   max_workers => $max_workers
+   max_workers => $max_workers,
+   gather => \&display_result
 );
 
 $start = time();
@@ -80,7 +81,7 @@ $start = time();
 $mce->foreach(\@input_data, sub {
    my ($self, $chunk_ref, $chunk_id) = @_;
    my $result = sqrt($chunk_ref->[0]);
-   $self->do('display_result', $result, $chunk_id);
+   MCE->gather($result, $chunk_id);
 });
 
 $end = time();
